aboutsummaryrefslogtreecommitdiffstats
path: root/chilbert/FixBitVec.hpp
diff options
context:
space:
mode:
authorDavid Robillard <d@drobilla.net>2018-08-11 18:12:11 +0200
committerDavid Robillard <d@drobilla.net>2018-09-29 14:46:18 +0200
commit59a618492e083291f50ac47cf2adc88dac33b6ce (patch)
tree40b5c3bac147324a86fc6c9146eb90c7d1d2f48a /chilbert/FixBitVec.hpp
parenta0a6ee8f787c07fb7ca5b63a52131660eed26586 (diff)
downloadchilbert-59a618492e083291f50ac47cf2adc88dac33b6ce.tar.gz
chilbert-59a618492e083291f50ac47cf2adc88dac33b6ce.tar.bz2
chilbert-59a618492e083291f50ac47cf2adc88dac33b6ce.zip
Rename toggle() to flip() to match std::bitset
Diffstat (limited to 'chilbert/FixBitVec.hpp')
-rw-r--r--chilbert/FixBitVec.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/chilbert/FixBitVec.hpp b/chilbert/FixBitVec.hpp
index bec5ba1..a1a415e 100644
--- a/chilbert/FixBitVec.hpp
+++ b/chilbert/FixBitVec.hpp
@@ -81,8 +81,8 @@ public:
return *this;
}
- /// Toggle the value of the `index`th bit
- CFixBitVec& toggle(const int index)
+ /// Flip the value of the `index`th bit
+ CFixBitVec& flip(const int index)
{
assert(0 <= index && index < FBV_BITS);
m_rack ^= (FBV1 << index);